@@ -1,11 +1,20 @@
 # Copyright 2016, Yahoo Inc.
 # Licensed under the terms of the Apache License, Version 2.0. See the LICENSE file associated with the project for terms.
-"""Generic or specific utilities"""
+"""
+Generic or specific utilities  without polluting imports.
+
+.. testsetup::
+
+    from graphtik.base import *
+    __name__ = "graphtik.base"
+"""
 
 import abc
 import logging
-from collections import defaultdict
-from typing import Any, Collection, List, Mapping, Union
+from collections import defaultdict, namedtuple
+from functools import partial, partialmethod, wraps
+from typing import Any, Collection, List, Mapping, NamedTuple, Optional
+from typing import Tuple, Union
 
 Items = Union[Collection, str, None]
 
@@ -98,6 +107,148 @@ def astuple(i, argname, allowed_types=tuple):
     return i
 
 
+def func_name(fn, default=..., mod=None, fqdn=None, human=None) -> Optional[str]:
+    """
+    FQDN of `fn`, descending into partials to print their args.
+
+    :param default:
+        What to return if it fails; by default it raises.
+    :param mod:
+        when true, prepend module like ``module.name.fn_name``
+    :param fqdn:
+        when true, use ``__qualname__`` (instead of ``__name__``)
+        which differs mostly on methods, where it contains class(es),
+        and locals, respectively (:pep:`3155`).
+        *Sphinx* uses `fqdn=True` for generating IDs.
+    :param human:
+        when true, partials denote their args like ``fn({"a": 1}, ...)`` in the returned text,
+        otherwise, just the (fqd-)name, appropriate for IDs.
+
+    :return:
+        a (possibly dot-separated) string, or `default` (unless this is ``...```).
+    :raises:
+        Only if default is ``...``, otherwise, errors debug-logged.
+
+
+    **Examples**
+
+        >>> func_name(func_name)
+        'func_name'
+        >>> func_name(func_name, mod=1)
+        'graphtik.base.func_name'
+        >>> func_name(MultiValueError.mro, fqdn=0)
+        'mro'
+        >>> func_name(MultiValueError.mro, fqdn=1)
+        'MultiValueError.mro'
+
+    Even functions defined in docstrings are reported:
+
+        >>> def f():
+        ...     def inner():
+        ...         pass
+        ...     return inner
+
+        >>> func_name(f, mod=1, fqdn=1)
+        'graphtik.base.f'
+        >>> func_name(f(), fqdn=1)
+        'f.<locals>.inner'
+
+    On failures, arg `default` controls the outcomes:
+
+    TBD
+    """
+    if isinstance(fn, (partial, partialmethod)):
+        # Always bubble-up errors.
+        fn_name = func_name(fn.func, default, mod, fqdn, human)
+        if human:
+            args = [str(i) for i in (fn.args, fn.keywords) if i]
+            args.append("...")
+            args_str = ", ".join(args)
+            fn_name = f"{fn_name}({args_str})"
+
+        return fn_name
+
+    try:
+        fn_name = fn.__qualname__ if fqdn else fn.__name__
+        assert fn_name
+
+        mod_name = getattr(fn, "__module__", None)
+        if mod and mod_name:
+            fn_name = ".".join((mod_name, fn_name))
+        return fn_name
+    except Exception as ex:
+        if default is ...:
+            raise
+        log.debug(
+            "Ignored error while inspecting %r name: %s", fn, ex,
+        )
+        return default
+
+
+def _un_partial_ize(func):
+    """
+    Alter functions working on 1st arg being a callable, to descend it if it's a partial.
+    """
+
+    @wraps(func)
+    def wrapper(fn, *args, **kw):
+        if isinstance(fn, (partial, partialmethod)):
+            return func(fn.func, *args, **kw)
+        return func(fn, *args, **kw)
+
+    return wrapper
+
+
+@_un_partial_ize
+def func_source(fn, default=..., human=None) -> Optional[Tuple[str, int]]:
+    """
+    Like :func:`inspect.getsource` supporting partials.
+
+    :param default:
+        If given, better be a 2-tuple respecting types,
+        or ``...``, to raise.
+    :param human:
+        when true, denote builtins like python does
+    """
+    import inspect
+
+    try:
+        if human and inspect.isbuiltin(fn):
+            return str(fn)
+        return inspect.getsource(fn)
+    except Exception as ex:
+        if default is ...:
+            raise
+        log.debug(
+            "Ignored error while inspecting %r sources: %s", fn, ex,
+        )
+        return default
+
+
+@_un_partial_ize
+def func_sourcelines(fn, default=..., human=None) -> Optional[Tuple[str, int]]:
+    """
+    Like :func:`inspect.getsourcelines` supporting partials.
+
+    :param default:
+        If given, better be a 2-tuple respecting types,
+        or ``...``, to raise.
+    """
+    import inspect
+
+    try:
+        if human and inspect.isbuiltin(fn):
+            return [str(fn)], -1
+        return inspect.getsourcelines(fn)
+    except Exception as ex:
+        if default is ...:
+            raise
+        log.debug(
+            "Ignored error while inspecting %r sourcelines: %s", fn, ex,
+        )
+        return default
+
+
 def jetsam(ex, locs, *salvage_vars: str, annotation="jetsam", **salvage_mappings):
     """
     Annotate exception with salvaged values from locals() and raise!
@@ -200,6 +351,59 @@ def jetsam(ex, locs, *salvage_vars: str, annotation="jetsam", **salvage_mappings
         raise ex2
 
 
+_PlotArgs_render_args = {"filename", "show", "jupyter_render"}
+
+
+class PlotArgs(NamedTuple):
+    """All the args of a :meth:`.Plottable.plot()` call. """
+
+    plotter: "Plotter" = None
+    graph: "nx.Graph" = None
+    name: str = None
+    steps: Collection = None
+    inputs: Collection = None
+    outputs: Collection = None
+    solution: "Solution" = None
+    clusters: Mapping = None
+    jupyter_render: Mapping = None
+    filename: str = None
+    show: Union[bool, int] = None
+
+    def clone_or_merge_graph(self, base_graph) -> "PlotArgs":
+        """
+        Overlay :attr:`graph` over `base_graph`, or clone `base_graph`, if no attribute.
+
+        :return:
+            the updated plot_args
+        """
+        import networkx as nx
+
+        if self.graph:
+            graph = nx.compose(base_graph, self.graph)
+        else:
+            graph = base_graph.copy()  # cloned, to freely annotate downstream
+
+        return self._replace(graph=graph)
+
+    def with_defaults(self, *args, **kw) -> "PlotArgs":
+        """Replace only fields with `None` values."""
+        return self._replace(
+            **{k: v for k, v in dict(*args, **kw).items() if getattr(self, k) is None}
+        )
+
+    @property
+    def kw_build_pydot(self) -> dict:
+        return {
+            k: v
+            for k, v in self._asdict().items()
+            if k not in _PlotArgs_render_args and k != "plotter"
+        }
+
+    @property
+    def kw_render_pydot(self) -> dict:
+        return {k: v for k, v in self._asdict().items() if k in _PlotArgs_render_args}
+
+
 ## Defined here, to avoid subclasses importing `plot` module.
 class Plottable(abc.ABC):
     """
@@ -215,19 +419,60 @@ class Plottable(abc.ABC):
         self,
         filename=None,
         show=False,
+        *,
+        plotter: "Plotter" = None,
+        graph: "networkx.Graph" = None,
+        name=None,
+        steps=None,
+        inputs=None,
+        outputs=None,
+        solution=None,
+        clusters=None,
         jupyter_render: Union[None, Mapping, str] = None,
-        **kws,
-    ):
+    ) -> "pydot.Dot":
         """
         Entry-point for plotting ready made operation graphs.
 
         :param str filename:
             Write diagram into a file.
             Common extensions are ``.png .dot .jpg .jpeg .pdf .svg``
-            call :func:`plot.supported_plot_formats()` for more.
+            call :func:`.plot.supported_plot_formats()` for more.
         :param show:
             If it evaluates to true, opens the  diagram in a  matplotlib window.
             If it equals `-1`, it plots but does not open the Window.
+        :param plotter:
+            an instance to handle plotting; if none, the :term:`installed plotter`
+            is used by default.
+        :param name:
+            if not given, dot-lang graph would is named "G"; necessary to be unique
+            when referring to generated CMAPs.
+            No need to quote it, handled by the plotter, downstream.
+        :param str graph:
+            (optional) A :class:`nx.Digraph` with overrides to merge with the graph provided
+            by underlying plottables (translated by the :term:`installed plotter`).
+
+            It may contain "public" or "private *graph*, *node* & *edge* attributes:
+
+            - "private" attributes: those starting with underscore(``_``),
+              handled by :term:`plotter`:
+
+              - ``_source`` *(graph)*: a non user-overridable attribute with values
+                used to select plotter-styles::
+
+                    netop | net | plan | solution | <'_source` missing>
+              - ``_fn_link_target`` & ``_fn_link_target`` *(node)*: if truthy,
+                override result 2-tuple of :meth:`_get_fn_link()`.
+              - ``_op_tooltip`` & ``_fn_tooltip`` *(node)*: if truthy,
+                override those derrived from :meth:`_make_op_tooltip()` &
+                :meth:`_make_op_tooltip()`.
+
+            - "public" attributes: reaching `Graphviz`_ as-is.
+
+              .. Note::
+
+                Remember to escape those values as `Graphviz`_ HTML-Like strings
+                (use :func:`.plot.graphviz_html_string()`).
+
         :param inputs:
             an optional name list, any nodes in there are plotted
             as a "house"
@@ -240,43 +485,20 @@ class Plottable(abc.ABC):
             It extracts more infos from a :class:`.Solution` instance, such as,
             if `solution` has an ``executed`` attribute, operations contained in it
             are  drawn as "filled".
-        :param name:
-            if given, dot-lang graph would not be named "G"; necessary to be unique
-            when referring to generated CMAPs.
-        :param title:
-            an optional string to display at the bottom of the graph
-        :param node_props:
-            an optional nested dict of Graphviz attributes for certain nodes
-        :param edge_props:
-            an optional nested dict of Graphviz attributes for certain edges
         :param clusters:
             an optional mapping of nodes --> cluster-names, to group them
-        :param splines:
-            Whether to plot `curved/polyline edges
-            <https://graphviz.gitlab.io/_pages/doc/info/attrs.html#d:splines>`_
-            [default: "ortho"]
         :param jupyter_render:
             a nested dictionary controlling the rendering of graph-plots in Jupyter cells,
-            if `None`, defaults to :data:`jupyter_render` (you may modify it in place
-            and apply for all future calls).
-        :param legend_url:
-            a URL to the *graphtik* legend; if it evaluates to false, none is added.
+            if `None`, defaults to :data:`jupyter_render`; you may modify it in place
+            and apply for all future calls (see :ref:`jupyter_rendering`).
 
         :return:
             a |pydot.Dot|_ instance
-            (for for API reference visit:
+            (for reference to as similar API to |pydot.Dot|_ instance, visit:
             https://pydotplus.readthedocs.io/reference.html#pydotplus.graphviz.Dot)
 
-            .. Tip::
-                The |pydot.Dot|_ instance returned is rendered directly
-                in *Jupyter/IPython* notebooks as SVG images.
-
-                You may increase the height of the SVG cell output with
-                something like this::
-
-                    netop.plot(jupyter_render={"svg_element_styles": "height: 600px; width: 100%"})
-
-                Check :data:`.default_jupyter_render` for defaults.
+            The |pydot.Dot|_ instance returned is rendered directly in *Jupyter/IPython*
+            notebooks as SVG images (see :ref:`jupyter_rendering`).
 
         Note that the `graph` argument is absent - Each Plottable provides
         its own graph internally;  use directly :func:`.render_pydot()` to provide
@@ -343,20 +565,37 @@ class Plottable(abc.ABC):
         >>> dot = netop.plot(solution=solution);   # just get the `pydot.Dot` object, renderable in Jupyter
         >>> print(dot)
         digraph netop {
-            fontname=italic;
-            label=<netop>;
-            splines=ortho;
-            <a> [fillcolor=wheat, shape=invhouse, style=filled, tooltip=1];
+        fontname=italic;
+        label=<netop>;
+        splines=ortho;
+        <a> [fillcolor=wheat, shape=invhouse, style=filled, tooltip="(int) 1"];
         ...
 
         """
-        from .plot import render_pydot
+        kw = locals().copy()
+        del kw["self"]
+        plot_args = PlotArgs(**kw)
 
-        dot = self._build_pydot(**kws)
-        return render_pydot(
-            dot, filename=filename, show=show, jupyter_render=jupyter_render
-        )
+        from .plot import Plotter, get_installed_plotter
+
+        if plotter and not isinstance(plotter, Plotter):
+            raise ValueError(f"Invalid `plotter` argument given: {plotter}")
+        plot_args = plot_args._replace(plotter=plotter or get_installed_plotter())
+
+        plot_args = self.prepare_plot_args(plot_args)
+        assert plot_args.graph, plot_args
+
+        return plot_args.plotter.plot(plot_args)
 
     @abc.abstractmethod
-    def _build_pydot(self, **kws):
+    def prepare_plot_args(self, plot_args: PlotArgs) -> PlotArgs:
+        """
+        Called by :meth:`plot()` to create the nx-graph and other plot-args, e.g. solution.
+
+        - Clone the graph or merge it with the one in the `plot_args`
+          (see :meth:`PlotArgs.clone_or_merge_graph()`.
+
+        - For the rest args, prefer :meth:`PlotArgs.with_defaults()` over :meth:`._replace()`,
+          not to override user args.
+        """
         pass
