@@ -1,6 +1,6 @@
 # Copyright 2016, Yahoo Inc.
 # Licensed under the terms of the Apache License, Version 2.0. See the LICENSE file associated with the project for terms.
-""":term:`Compile` & :term:`execute` network graphs of operations."""
+""":term:`compile` & :term:`execute` network graphs of operations."""
 import copy
 import logging
 import random
@@ -15,7 +15,7 @@ from typing import Any, Callable, Collection, List, Mapping, Optional, Tuple, Un
 import networkx as nx
 from boltons.setutils import IndexedSet as iset
 
-from .base import UNSET, Items, Plottable, aslist, astuple, jetsam
+from .base import UNSET, Items, PlotArgs, Plottable, aslist, astuple, jetsam
 from .config import (
     get_execution_pool,
     is_abort,
@@ -64,7 +64,7 @@ class IncompleteExecutionError(Exception):
     """
 
     def __str__(self):
-        return self.args[0]
+        return self.args[0]  # pylint: disable=unsubscriptable-object
 
 
 def _unsatisfied_operations(dag, inputs: Collection) -> List:
@@ -175,10 +175,12 @@ class Solution(ChainMap, Plottable):
         self.is_parallel = is_parallel_tasks()
         self.is_marshal = is_marshal_tasks()
 
-        ## Clone will be modified, by removing the downstream edges of:
-        #  - any partial outputs not provided, or
-        #  - all `provides` of failed operations.
-        # FIXME: SPURIOUS dag reversals on multi-threaded runs (see below next assertion)!
+        #: Cloned from `plan` will be modified, by removing the downstream edges of:
+        #:
+        #: - any partial outputs not provided, or
+        #: - all `provides` of failed operations.
+        #:
+        #: FIXME: SPURIOUS dag reversals on multi-threaded runs (see below next assertion)!
         self.dag = plan.dag.copy()
         # assert next(iter(dag.edges))[0] == next(iter(plan.dag.edges))[0]:
 
@@ -335,12 +337,14 @@ class Solution(ChainMap, Plottable):
         if ex:
             raise ex
 
-    def _build_pydot(self, **kws):
-        """delegate to network"""
-        kws.setdefault("name", f"solution-x{len(self.plan.net.graph.nodes)}-nodes")
-        kws.setdefault("solution", self)
-        plotter = self.plan
-        return plotter._build_pydot(**kws)
+    def prepare_plot_args(self, plot_args: PlotArgs) -> PlotArgs:
+        """delegate to plan, with solution"""
+        name = f"solution-x{len(self.plan.net.graph.nodes)}-nodes"
+        plot_args = plot_args.with_defaults(name=name, solution=self)
+        plot_args = self.plan.prepare_plot_args(plot_args)
+        plot_args.graph.graph["_source"] = "solution"
+
+        return plot_args
 
 
 class _DataNode(str):
@@ -498,23 +502,22 @@ class ExecutionPlan(
         otherwise, *evictions* (along with prefect-evictions check) are skipped.
     """
 
-    def _build_pydot(self, **kws):
-        from .plot import build_pydot
+    def prepare_plot_args(self, plot_args: PlotArgs) -> PlotArgs:
+        plot_args = plot_args.clone_or_merge_graph(self.net.graph)
+        graph = plot_args.graph
 
         clusters = None
-        if self.dag.nodes != self.net.graph.nodes:
+        if self.dag.nodes != graph.nodes:
             clusters = {n: "after pruning" for n in self.dag.nodes}
-        mykws = {
-            "graph": self.net.graph,
-            "name": f"plan-x{len(self.net.graph.nodes)}-nodes",
-            "steps": self.steps,
-            "inputs": self.needs,
-            "outputs": self.provides,
-            "clusters": clusters,
-        }
-        mykws.update(kws)
 
-        return build_pydot(**mykws)
+        graph.graph["_source"] = "plan"
+        return plot_args.with_defaults(
+            name=f"plan-x{len(graph.nodes)}-nodes",
+            steps=self.steps,
+            inputs=self.needs,
+            outputs=self.provides,
+            clusters=clusters,
+        )
 
     def __repr__(self):
         needs = aslist(self.needs, "needs")
@@ -914,6 +917,8 @@ class Network(Plottable):
             if not isinstance(graph, nx.Graph):
                 raise ValueError(f"Must be a NetworkX graph, was: {graph}")
 
+        #: The :mod:`networkx` (Di)Graph containing all operations and dependencies,
+        #: prior to :term:`compilation`.
         self.graph = graph
 
         for op in operations:
@@ -933,15 +938,15 @@ class Network(Plottable):
         )
         return f"Network(x{len(self.graph.nodes)} nodes, x{len(ops)} ops: {''.join(steps)})"
 
-    def _build_pydot(self, **kws):
-        from .plot import build_pydot
-
-        kws.setdefault("graph", self.graph)
-        kws.setdefault("name", f"network-x{len(self.graph.nodes)}-nodes")
-        kws.setdefault("inputs", self.needs)
-        kws.setdefault("outputs", self.provides)
-
-        return build_pydot(**kws)
+    def prepare_plot_args(self, plot_args: PlotArgs) -> PlotArgs:
+        plot_args = plot_args.clone_or_merge_graph(self.graph)
+        plot_args.with_defaults(
+            name=f"network-x{len(self.graph.nodes)}-nodes",
+            inputs=self.needs,
+            outputs=self.provides,
+        )
+        plot_args.graph.graph["_source"] = "net"
+        return plot_args
 
     def _append_operation(self, graph, operation: Operation):
         """
