@@ -44,8 +44,15 @@ class GraphtikPlotsBuilder(doctestglobs.ExposeGlobalsDocTestBuilder):
         return HistoricDict()
 
     def _warn_out(self, text: str) -> None:
-        """Silence warnings since urelated to building site. """
-        log.info(f"WARN-like: {text}", nonl=True)
+        """
+        Silence warnings since errors unrelated to building site, ...
+
+        unless :rst:confval`graphtik_warning_is_error` is true (default false).
+        """
+        if self.config.graphtik_warning_is_error:
+            super()._warn_out(text)
+        else:
+            log.info(f"WARN-like: {text}", nonl=True)
         self.outfile.write(text)
 
     def _globals_updated(self, code: extdoctest.TestCode, globs: dict):
@@ -57,9 +64,11 @@ class GraphtikPlotsBuilder(doctestglobs.ExposeGlobalsDocTestBuilder):
                 globs, node["graphvar"], (code.filename, code.lineno)
             )
             if plottable:
-                dot: pydot.Dot = plottable if isinstance(
-                    plottable, pydot.Dot
-                ) else plottable.plot()
+                dot: pydot.Dot
+                if isinstance(plottable, pydot.Dot):
+                    dot = plottable
+                else:
+                    dot = plottable.plot(**self.config.graphtik_plot_keywords)
                 img_format = node["img_format"]
                 rel_img_path = self._render_dot_image(img_format, dot, node)
                 dot_str = (
@@ -131,23 +140,39 @@ class GraphtikPlotsBuilder(doctestglobs.ExposeGlobalsDocTestBuilder):
     ) -> Path:
         """
         Ensure png(+usemap)|svg|svgz|pdf file exist, and return its path.
+
+        :raises:
+            any exception from Graphviz program
         """
         ## Derrive image-filename from graph contents.
-        #
+        #  TODO: don't derrive image-filename from sha1 contents!
+        #        copy from http://www.sphinx-doc.org/en/stable/extdev/tutorial.html
+        #  TODO: delete old images (see event todo-tutorial)
         hasher = sha1()
         hasher.update(str(dot).encode())
         fname = f"graphtik-{hasher.hexdigest()}.{img_format}"
         abs_fpath = Path(self.outdir, self.imagedir, fname)
 
-        ## Don not re-write images, thay have content-named path,
+        ## Do not re-write images, that have content-named path,
         #  so they are never out-of-date.
         #
+        self.env.graphtik_image_purgatory.register_doc_fpath(
+            self.env.docname, abs_fpath
+        )
+        if self.config.graphtik_save_dot_files:
+            self.env.graphtik_image_purgatory.register_doc_fpath(
+                self.env.docname, abs_fpath.with_suffix(".txt")
+            )
+
         if not abs_fpath.is_file():
             abs_fpath.parent.mkdir(parents=True, exist_ok=True)
             dot.write(abs_fpath, format=img_format)
             if img_format == "png":
                 cmap = dot.create(format="cmapx", encoding="utf-8").decode("utf-8")
                 node.cmap = cmap
+            if self.config.graphtik_save_dot_files:
+                with open(abs_fpath.with_suffix(".txt"), "w") as f:
+                    f.write(str(dot))
 
         ## XXX: used to work till active-builder attributes were transfered to self.
         # rel_fpath = Path(self.imgpath, fname)
